// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// BackscaleMaker.cc
//
// Authors:  Richard Saxton (VEGA/ESA)
//           ESA XMM SOC
//
// Description: Runs backscale to produce an ARF
//
#include <Tracer.h>
#include <metatask.h>
#include <errstr.h>
#include <param.h>

//#include <backscale.h>   // tasks

#include "BackscaleMaker.h"

BackscaleMaker::BackscaleMaker(string spectrumset, bool withbadpixcorr, 
                    bool useodfatt, string badpixlocation)
{
  PROC;

  /* Set up the parameters for calling backscale */
    openParameters("backscale");

  /* First the input parameters */
    setParameter("spectrumset",spectrumset);
    setParameter("withbadpixcorr",withbadpixcorr);
    setParameter("useodfatt",useodfatt);
    setParameter("badpixlocation",badpixlocation);

  /* Now run backscale using these parameters */ 
    task(backscale);
   
  /* Shutdown */
    closeParameters();

  ENDPROC;
}

BackscaleMaker::~BackscaleMaker()
{
  PROC;
  ENDPROC;
}

