// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
// This  skeleton file was automatically created by 
//            pkgmaker 0.1
//            Thursday, December 11 1997
// 
// Module: EnergySpectrum
// Author: Richard Saxton
//
// Description: Provides an interface to data consisting of a value 
//              indexed by an energy value
// 
// Comments: 
//  
// Modifications: See ChangeLog
// 
// $Id: EnergySpectrum.h,v 1.1 2013/06/06 15:57:39 rsaxton Exp $

#ifndef EnergySpectrum_H
#define EnergySpectrum_H

// General classes
#include<cassert>

#include <string>
#include <iostream>
#include <vector>
#include <map>

// SAS-specific classes

#include "Dal.h"
#include "errstr.h"

// Utility functions
#include "Tracer.h"

// -----------------------------------------------------------------------------------

// class EnergySpectrum

// Supports data consisting of an energy, energy width and data value

// -----------------------------------------------------------------------------------

class EnergySpectrum
{

public:

  /* Constructor from input vectors */
  EnergySpectrum(vector<float> energy, vector<float> energy_width, 
                 vector<float> value);

  /* Destructor */
  ~EnergySpectrum();


// Access methods
  int size() const;

    /* Purpose:Returns the number of elements in the arrays */

  float value(float energy) const;

    /* Purpose: Returns the value of the third array at the input energy
		interpolating or extrapolating as necessary */

  float value(int i) const;

    /* Purpose: Returns the ith element of the third array */

  float value(unsigned i) const;

    /* Purpose: Returns the ith element of the third array */

  float sum() const;

    /* Purpose: Returns the sum of all elements */

  vector<float> energy() const;

    /* Purpose: Returns the energy array */

  vector<float> energyWidth() const;
  
    /* Purpose: Returns the energy width array */

protected:

  // Variables inherited by classes which extend EnergySpectrum
  vector<float> _energy,
                 _energyWidth,
                 _value;

  int _N; // Number of elements in the arrays

  // Suppress default constructor
  EnergySpectrum(){};

};


#endif




