// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// Module: Eradial
// Author: Richard Saxton 
//
// Description: Main class for calculating  a source radial profile
//
// Modifications: See ChangeLog
//

#ifndef Eradial_H
#define Eradial_H

/* General classes */
#include <iostream>

/* SAS-specific classes */
#include <Tracer.h>
#include <metatask.h>
#include <errstr.h>
#include <param.h>
#include <Dal.h>
#include <Xmm.h>
#include "CalServer.h"
#include "STime.h"

/* Local Classes */
#include "ImageRegion.h"
#include "CalSetter.h"


/****************************************************
 *
 * class Eradial
 *
 ***************************************************/

class Eradial
{
public:

  /* Constructor */
  Eradial();

  /* Destructor */
  ~Eradial();

  /* Set the accuracy level as specified by the user */
  void setPsfType(string & psfType) const; 

  /* Get the PSF radial profile */
  vector<double> calcPsfArray(ImageRegion::RadialProfile r, 
                         double energy, double theta, double phi);

  /* Write the output file */
  const void writerpfile(DataSet * rpset, ImageRegion::RadialProfile r,
                  vector<double> psfdata, double * bestFitPSF,
		  double * linCoeffs, double rms, 
                  DatafileAttributes * imgatts) const;

//  const string getPostFix();

private:


  /* Member fields */
  ImageRegion * srcreg;
  CalSetter * _calset;
  string  _postfix;
};

#endif

