// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// Module: LightCurveMaker
// Author: Richard Saxton 
//
// Description: Creates a spectrum using evselect
//
// Modifications: See ChangeLog
//

#ifndef LightCurveMaker_H
#define LightCurveMaker_H

/* General classes */
#include <iostream>

/* SAS-specific classes */
#include <Tracer.h>
#include <metatask.h>
#include <errstr.h>
#include <param.h>
#include <Dal.h>
#include <Xmm.h>

/* Local Classes */
#include <DatafileAttributes.h>

/****************************************************
 *
 * class LightCurveMaker
 *
 ***************************************************/

class LightCurveMaker
{
public:

  /* Constructor */
  LightCurveMaker(string lcurvefile, DatafileAttributes * timeAttributes, 
                  string expression, double timebin);

  /* Destructor */
  ~LightCurveMaker();

private:


  /* Member fields */

  Xmm::Instrument       _instrumentID;
  string               _instr;
  string               _lcurvefile;
  string               _flagexp;
  string               _pattexp;
  double               _timebin;

};

#endif

